#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#
%define enable_autotools 1

%if 0%{?fedora}
%global		with_python3 1
%global		__python_bin %{__python3}
%global		__python_sitelib %{python3_sitelib}
%else
%global		__python_bin %{__python2}
%global		__python_sitelib %{python2_sitelib}
%endif

%if 0%{?fedora}
%global ovirt_rh_postgresql95 0
%else
%global ovirt_rh_postgresql95 1
%endif

%global		package_version 4.2.5
%global		package_name ovirt-log-collector

Summary:	Log Collector for oVirt Engine
Name:		%{package_name}
Version:	4.2.5
Release:	2%{?release_suffix}%{?dist}
License:	ASL 2.0
URL:		http://www.ovirt.org
Source0:	http://resources.ovirt.org/pub/src/%{package_name}/%{package_name}-%{package_version}.tar.gz

BuildArch:	noarch

Requires:	logrotate
Requires:	openssl
Requires:	openssh-clients
Requires:	sos >= 3.3

Requires:	ovirt-engine-lib

BuildRequires:	gettext

%if 0%{?enable_autotools}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: gettext-devel
%endif

%if 0%{?with_python3}
Requires:	python3
Requires:	python3-dateutil
Requires:	python3-lxml
Requires:	python3-ovirt-engine-sdk4 >= 4.2.0
BuildRequires:	python3-devel
%else
Requires:	python
Requires:	python-dateutil
Requires:	python-lxml
Requires:	python-ovirt-engine-sdk4 >= 4.2.0
BuildRequires:	python2-devel
%endif

%description
Log Collector tool for oVirt Engine

%package analyzer
Summary:	Log Collector for oVirt Engine - Analysis tools
Requires:	rubygem-asciidoctor
Requires:	libxml2

%if %{ovirt_rh_postgresql95}
Requires:       rh-postgresql95-postgresql-server
%else
Requires:       postgresql-server
%endif

Requires:	coreutils
License:	ASL 2.0 and GPLv2+

%description analyzer
This package contains tools to help analyze oVirt Log Collector archives

%prep
%setup -q -n %{package_name}-%{package_version}

%build
%configure \
	--docdir="%{_docdir}/%{package_name}-%{version}" \
	--disable-python-syntax-check \
	PYTHON="%{__python_bin}"
make %{?_smp_mflags}

%check
make check

%install
rm -rf "%{buildroot}"
make %{?_smp_mflags} install DESTDIR="%{buildroot}"

%files
%doc AUTHORS
%license COPYING
%dir %{_localstatedir}/log/ovirt-engine/%{package_name}
%dir %{_sysconfdir}/ovirt-engine/logcollector.conf.d
%config(noreplace) %{_sysconfdir}/ovirt-engine/logcollector.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{package_name}
%{__python_sitelib}/ovirt_log_collector/
%{_bindir}/ovirt-log-collector
%{_mandir}/man8/ovirt-log-collector.8*

%files analyzer
%doc AUTHORS
%license COPYING
%license COPYING-GPL
%{_bindir}/ovirt-log-collector-analyzer
%dir %{_datadir}/%{name}/analyzer
%{_datadir}/%{name}/analyzer/
%{_mandir}/man8/ovirt-log-collector-analyzer.8*

%changelog
* Fri Apr 20 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.2.5-2
- rebase upstream

* Fri Feb 23 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.2.4-5
- inventory: Check engine db backup
- inventory: handle to postgresql dumps from sosreport
- analyzer: Fix Vdsm Name column value

* Tue Feb 20 2018 Sandro Bonazzola <sbonazzo@redhat.com> - 4.2.4-1
- Rebase on upstream 4.2.4

* Fri Jan 19 2018 Douglas Schilling Landgraf <dougsland@redhat.com> - 4.2.3-1
- Rebase upstream

* Thu Jan 11 2018 Sandro Bonazzola <sbonazzo@redhat.com> - 4.2.1-1
- 4.2.1-1

* Wed Nov 29 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.2.0-1
- Rebase on upstream 4.2.0
- Resolves: BZ#1020790
- Resolves: BZ#1404509
- Resolves: BZ#1441258
- Resolves: BZ#1445245
- Resolves: BZ#1456888
- Resolves: BZ#1490447
- Resolves: BZ#1495267

* Thu Jan 19 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 4.1.0-1
- Rebase on upstream 4.1.0
- Resolves: BZ#1381265

* Tue Aug 30 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.0.1-1
- Rebase on upstream 4.0.1
- Resolves: BZ#1371405
- Resolves: BZ#1330759
- Resolves oVirt BZ#1363684
- Resolves oVirt BZ#1355966

* Tue May 31 2016 Rafael Martins <rmartins@redhat.com> - 4.0.0-1
- 4.0.0-1

* Wed May 18 2016 Rafael Martins <rmartins@redhat.com> - 4.0.0-0.2.master.git3218ba1
- 4.0.0.0.2.master.git3218ba1

* Mon Mar 14 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 4.0.0-0.1.master.git668ba27
- 4.0.0-0.1.master.git668ba27

* Wed Aug  5 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 4.0.0-0.0.master.gitcfad1e5
- 4.0.0-0.0.master.gitcfad1e5
- Resolves: BZ#1210800
